Struct Error
struct Error(_)
A small and no_std compatible error type
The [Error::raw_os_error()] will indicate if the error is from the OS, and
if so, which error code the OS gave the application. If such an error is
encountered, please consult with your system documentation.
If this crate's "std" Cargo feature is enabled, then:
- [
getrandom::Error][Error] implementsstd::error::Error std::io::ErrorimplementsFrom<getrandom::Error>.
Implementations
impl Error
fn raw_os_error(self: Self) -> Option<i32>Extract the raw OS error code (if this error came from the OS)
This method is identical to
std::io::Error::raw_os_error(), except that it works inno_stdcontexts. On most targets this method returnsOption<i32>, but some platforms (e.g. UEFI) may use a different primitive type likeusize. Consult with theRawOsErrordocs for more information.If this method returns
None, the error value can still be formatted via theDisplayimplementation.const fn new_custom(n: u16) -> ErrorCreates a new instance of an
Errorfrom a particular custom error code.
impl Clone for Error
fn clone(self: &Self) -> Error
impl Copy for Error
impl Debug for Error
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for Error
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Error
impl Error for Error
impl Freeze for Error
impl PartialEq for Error
fn eq(self: &Self, other: &Error) -> bool
impl RefUnwindSafe for Error
impl Send for Error
impl StructuralPartialEq for Error
impl Sync for Error
impl Unpin for Error
impl UnsafeUnpin for Error
impl UnwindSafe for Error
impl<T> Any for Error
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Error
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Error
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Error
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Error
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Error
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for Error
fn to_string(self: &Self) -> String
impl<T, U> Into for Error
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Error
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Error
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>